animated_containers library

Classes

AnFlexible
A widget that controls how a child of an AnimatedFlex flexes.
AnimatedColumn
A widget that displays its children in a vertical array with animations.
AnimatedFlex
A widget that displays its children in a one-dimensional array.
AnimatedFlexParentData
How the child is inscribed into the available space.
AnimatedRenderFlex
Displays its children in a one-dimensional array.
AnimatedRow
A widget that displays its children in a horizontal array with animations.
AnimatedWrap
An animated version of Wrap that smoothly transitions children when their positions change.
AnimatedWrapParentData
Parent data for use with AnimatedWrapRender.
AnimatedWrapRender
Displays its children in multiple horizontal or vertical runs.
AnimatedWrapState
BumpPulse
DuoMovementSimulation
Forms a 2d simulation by just combining two Simulations in the x and y directions. Which is imperfect because instead of modelling an object that aims one thruster optimally, it's like it models an object with four thrusters pointing in cardinal directions, which is a weird object, but it looks fine, perhaps even better.
DynamicEaseInOutAnimationController
An animation controller that uses DynamicEaseInOut to allow smooth retargeting of animations. When the target value changes, the animation smoothly reorients without any discontinuities in velocity.
DynamicEaseInOutSimulation
A simulation that can be interrupted and reoriented with no discontinuities in velocity. Used in DynamicEaseInOutAnimationController, and SmoothV2
Insertion
InsertionPoint
a position at which a child can be inserted
MovementSimulationAnimationController
An animation controller that can be told to target a position, and it smoothly moves to it
OffsetSimulation
regular Simulations target a one-dimensional number, this one targets a point in 2D space, though it's usually constructed by just taping together two Simulations in a DuoMovementSimulation
Pulser
PulserFold<T>
pulses to 1 and sags to 0. Is fairly graceful when interrupted, allowing pulses to overlap. T is a fold over the pulse
RanimatedContainer
A Container but animates in a way that's well suited to layout animations. We can define "ranimation" as a way of implementing animation where the layout update is instant (where in a sense it has already ran), but where the visuals move to the new layout smoothly. It has many advantages:
SizeChangeReporter
A widget that reports the size of its child via a callback.
SmoothOffset
SmoothOffsetEaser

Enums

AnimatedWrapCrossAlignment
How AnimatedWrap should align children within a run in the cross axis.

Functions

anti(double v) double
clampUnit(double v) double
constantAccelerationEaseInOutWithInitialVelocity(double t, double initialVelocity) double
defaultPulserFunction(double v) double
delayAnimation(Animation<double> animation, {required Duration by, required Duration total}) Animation<double>
delayedAnimation(Animation<double> animation, {required Duration duration, required Duration within}) Animation<double>
returns an animation with duration broader, but doesn't raise from 0 until broader - duration, meaning that it will appear as if it runs for duration after a delay. We do it this way instead of specifying {delay, duration} because flutter requires the duration to have been decided generally before you receive an animation, so this ends up being more succinct/parametizable.
delayedCurve({required Duration by, required Duration total, Curve curve = Curves.linear}) Interval
distributeWrapSpace(WrapAlignment alignment, double freeSpace, double itemSpacing, int itemCount) → (double, double)
duoEaseMovementConstructorOf(Duration duration) MovementSimulationConstructor
basic movement constructors for your movement constructor needs
ease(double startValue, double endValue, double startTime, double endTime, double currentTime, double initialVelocity) double
easeOffset(Offset startValue, Offset endValue, double startTime, double endTime, double currentTime, Offset initialVelocity) Offset
easeValVel(double startValue, double endValue, double startTime, double endTime, double currentTime, double initialVelocity) → (double, double)
easeValVelOffset(Offset startValue, Offset endValue, double startTime, double endTime, double currentTime, Offset initialVelocity) → (Offset, Offset)
flipOffset(Offset o) Offset
flipSize(Size s) Size
linearAccelerationEaseInOutWithInitialVelocity(double t, double initialVelocity) double
maxDuration(Duration a, Duration b) Duration
sq(double a) double
velEase(double startValue, double endValue, double startTime, double endTime, double currentTime, double initialVelocity) double
velocityOfConstantAccelerationEaseInOutWithInitialVelocity(double t, double initialVelocity) double
velocityOfLinearAccelerationEaseInOutWithInitialVelocity(double t, double initialVelocity) double

Typedefs

MovementSimulationConstructor = OffsetSimulation Function(Offset prevx, Offset prevdx, Offset newTarget)