AnimatedWrapParentData class

Parent data for use with AnimatedWrapRender.

Inheritance

Constructors

AnimatedWrapParentData()

Properties

hashCode int
The hash code for this object.
no setterinherited
nextSibling RenderBox?
The next sibling in the parent's child list.
getter/setter pairinherited
offset Offset
The offset at which to paint the child in the parent's coordinate system.
getter/setter pairinherited
previousOffset Offset
getter/setter pair
previousSibling RenderBox?
The previous sibling in the parent's child list.
getter/setter pairinherited
previousVelocity Offset
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detach() → void
Clear the sibling pointers.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited