AnimatedWrapRender constructor
AnimatedWrapRender({
- List<
RenderBox> ? children, - Axis direction = Axis.horizontal,
- WrapAlignment alignment = WrapAlignment.start,
- double spacing = 0.0,
- WrapAlignment runAlignment = WrapAlignment.start,
- double runSpacing = 0.0,
- AnimatedWrapCrossAlignment crossAxisAlignment = AnimatedWrapCrossAlignment.start,
- TextDirection? textDirection,
- VerticalDirection verticalDirection = VerticalDirection.down,
- Clip clipBehavior = Clip.none,
- required AnimationController animation,
- double sensitivity = 5.0,
Creates a wrap render object.
By default, the wrap layout is horizontal and both the children and the runs are aligned to the start.
Implementation
AnimatedWrapRender({
List<RenderBox>? children,
Axis direction = Axis.horizontal,
WrapAlignment alignment = WrapAlignment.start,
double spacing = 0.0,
WrapAlignment runAlignment = WrapAlignment.start,
double runSpacing = 0.0,
AnimatedWrapCrossAlignment crossAxisAlignment =
AnimatedWrapCrossAlignment.start,
TextDirection? textDirection,
VerticalDirection verticalDirection = VerticalDirection.down,
Clip clipBehavior = Clip.none,
required AnimationController animation,
double sensitivity = 5.0,
// Simulation Function(Offset position, Offset velocity)? moveSimulationConstructor,
}) : _direction = direction,
_alignment = alignment,
_spacing = spacing,
_runAlignment = runAlignment,
_runSpacing = runSpacing,
_crossAxisAlignment = crossAxisAlignment,
_textDirection = textDirection,
_verticalDirection = verticalDirection,
_clipBehavior = clipBehavior,
_animation = animation,
_sensitivity = sensitivity {
animation.addListener(() {
markNeedsPaint();
});
addAll(children);
}