InsertionPoint class
a position at which a child can be inserted
Constructors
- InsertionPoint({required int index, required bool insertingAfter, required Offset position, bool inserterWide = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- inserterWide → bool
-
is wide when it's not inserting at a between point, in which case a narrow selector visual wouldn't look right
final
- insertingAfter → bool
-
final
- insertionIndex → int
-
the index to be inserted into if you're doing an insertion
no setter
- position → Offset
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited